@@ -17,9 +17,10 @@
 
 
 import re
+from collections import defaultdict
 from datetime import date
 from pathlib import Path
-from typing import Dict, List, Optional, Union
+from typing import NamedTuple, Optional, TypedDict, Union
 
 import tomlkit
 
@@ -39,10 +40,164 @@ DEFAULT_CHANGELOG_CONFIG = """commit_types = [
 """
 
 
+class CommitType(TypedDict):
+    message: str
+    group: str
+
+
+class CommitLogEntry(NamedTuple):
+    commit_id: str
+    message: str
+
+
+class ConventionalCommits:
+    """
+    Extracts conventional commits from the git log
+
+    Example:
+        Collect the conventional commits between the tags "v1.2.3" and "v2.0.0"
+        using the default config settings. Afterwards get the list of commits
+        for the "Added" category.
+
+        .. code-block:: python
+
+            from pontos.changelog import ConventionalCommits
+
+            collector = ConventionalCommits(space="my-org", project="my-project)
+            commits = collector.get_commits(
+                from_ref="v1.2.3",
+                to_ref="v2.0.0",
+            )
+            added = commits.get("Added")
+    """
+
+    def __init__(
+        self,
+        config: Optional[Path] = None,
+    ) -> None:
+        """
+        Create a new ConventionalCommits instance for collecting conventional
+        commits from a git log.
+
+        Args:
+            config: Optional TOML config for conventional commit parsing
+                settings.
+        """
+        if config:
+            if not config.exists():
+                raise ChangelogBuilderError(
+                    f"Changelog Config file '{config.absolute()}' does not "
+                    "exist."
+                )
+
+            self._config = tomlkit.parse(config.read_text(encoding="utf-8"))
+        else:
+            self._config = tomlkit.parse(DEFAULT_CHANGELOG_CONFIG)
+
+    def get_commits(
+        self,
+        from_ref: Optional[SupportsStr] = None,
+        to_ref: SupportsStr = "HEAD",
+    ) -> dict[str, list[CommitLogEntry]]:
+        """
+        Get all commits by conventional commit type between a range of git
+        references.
+
+        Args:
+            from_ref: Git commit ID or reference where to start looking for
+                conventional commits. If None, to_ref is ignored and all
+                 conventional commits are returned.
+            to_ref: Git commit ID or reference where to stop looking for
+                conventional commits. By default HEAD is used.
+
+        Returns:
+            A dict containing the grouped log entries
+        """
+        commit_list = self._get_git_log(from_ref, to_ref)
+        return self._sort_commits(commit_list)
+
+    def commit_types(self) -> list[CommitType]:
+        return self._config.get("commit_types", [])
+
+    def _get_git_log(
+        self, from_ref: Optional[SupportsStr], to_ref: SupportsStr = "HEAD"
+    ) -> list[str]:
+        """Getting the git log for the a range of commits.
+
+        Requires the fitting branch to be checked out if to_ref is not set.
+
+        Args:
+            from_ref: Git commit ID or reference of the first log entry. If
+                None, to_ref is ignored and all log entries of the current
+                checked out branch are returned.
+            to_ref: Git commit ID or reference where to stop considering the
+                log entries. By default HEAD is used which points to the last
+                commit of the checked out branch.
+
+        Returns:
+            A list of `git log` entries
+        """
+        git = Git()
+        if not from_ref:
+            return git.log(oneline=True)
+
+        return git.log(
+            f"{from_ref}..{to_ref}",
+            oneline=True,
+        )
+
+    def _sort_commits(
+        self, commits: list[str]
+    ) -> dict[str, list[CommitLogEntry]]:
+        """Sort the commits by commit type and group them
+        in a dict
+        ```
+        {
+            'Added:': [
+                ('commit 1', 'message 1'),
+                ('commit 2', 'message 2'),
+                '...',
+            ],
+            'Fixed:': [
+                ...
+            ],
+        }
+        ```
+
+        Returns
+            The dict containing the commit messages
+        """
+        expressions = [
+            (
+                commit_type["group"],
+                re.compile(rf'{commit_type["message"]}\s?[:|-]', flags=re.I),
+            )
+            for commit_type in self.commit_types()
+        ]
+        commit_dict = defaultdict(list)
+        if commits and len(commits) > 0:
+            for commit in commits:
+                commit_id, message = commit.split(" ", maxsplit=1)
+                for group, reg in expressions:
+                    match = reg.match(message)
+                    if match:
+                        # remove the commit tag from commit message
+                        cleaned_msg = message.replace(
+                            match.group(0), ""
+                        ).strip()
+                        commit_dict[group].append(
+                            CommitLogEntry(
+                                commit_id=commit_id, message=cleaned_msg
+                            )
+                        )
+
+        return commit_dict
+
+
 class ChangelogBuilder:
     """
     Creates Changelog from conventional commits using the git log
-    from the latest tag.
+    from the latest version.
 
     Example:
         Create a changelog as a string from the changes between git tags
@@ -77,21 +232,11 @@ class ChangelogBuilder:
                 Default is "v".
             config: TOML config for conventional commit parsing settings
         """
-        if config:
-            if not config.exists():
-                raise ChangelogBuilderError(
-                    f"Changelog Config file '{config.absolute()}' does not "
-                    "exist."
-                )
+        self._project = project
+        self._space = space
 
-            self.config = tomlkit.parse(config.read_text(encoding="utf-8"))
-        else:
-            self.config = tomlkit.parse(DEFAULT_CHANGELOG_CONFIG)
-
-        self.project = project
-        self.space = space
-
-        self.git_tag_prefix = git_tag_prefix
+        self._git_tag_prefix = git_tag_prefix
+        self._conventional_commits = ConventionalCommits(config)
 
     def create_changelog(
         self,
@@ -112,7 +257,9 @@ class ChangelogBuilder:
         Returns:
             The created changelog content.
         """
-        commit_dict = self.get_commits(last_version)
+        commit_dict = self._conventional_commits.get_commits(
+            f"{self._git_tag_prefix}{last_version}" if last_version else None
+        )
         return self._build_changelog(last_version, next_version, commit_dict)
 
     def create_changelog_file(
@@ -138,23 +285,6 @@ class ChangelogBuilder:
         )
         self._write_changelog_file(changelog, output)
 
-    def get_commits(
-        self,
-        last_version: Optional[SupportsStr] = None,
-    ) -> Dict[str, List[str]]:
-        """
-        Get all commits by conventional commit type
-
-        Args:
-            last_version: Version of the last release. If None it is considered
-                as the first release.
-
-        Returns:
-            A dict containing the grouped commit messages
-        """
-        commit_list = self._get_git_log(last_version)
-        return self._sort_commits(commit_list)
-
     def _get_first_commit(self) -> str:
         """
         Git the first commit ID for the current branch
@@ -162,77 +292,11 @@ class ChangelogBuilder:
         git = Git()
         return git.rev_list("HEAD", max_parents=0, abbrev_commit=True)[0]
 
-    def _get_git_log(self, last_version: Optional[SupportsStr]) -> List[str]:
-        """Getting the git log for the next version.
-
-        Requires the fitting branch to be checked out
-
-        Returns:
-            A list of `git log` entries
-        """
-        git = Git()
-        if not last_version:
-            return git.log(oneline=True)
-
-        git_version = f"{self.git_tag_prefix}{last_version}"
-        return git.log(
-            f"{git_version}..HEAD",
-            oneline=True,
-        )
-
-    def _sort_commits(self, commits: List[str]) -> Dict[str, List[str]]:
-        """Sort the commits by commit type and group them
-        in a dict
-        ```
-        {
-            'Added:': [
-                'commit 1 [1234567](..)',
-                'commit 2 [1234568](..)',
-                '...',
-            ],
-            'Fixed:': [
-                ...
-            ],
-        }
-        ```
-
-        Returns
-            The dict containing the commit messages
-        """
-        # get the commit types from the toml
-        commit_types = self.config.get("commit_types")
-
-        commit_link = f"{ADDRESS}{self.space}/{self.project}/commit/"
-
-        commit_dict = {}
-        if commits and len(commits) > 0:
-            for commit in commits:
-                commit = commit.split(" ", maxsplit=1)
-                for commit_type in commit_types:
-                    reg = re.compile(
-                        rf'{commit_type["message"]}\s?[:|-]', flags=re.I
-                    )
-                    match = reg.match(commit[1])
-                    if match:
-                        if commit_type["group"] not in commit_dict:
-                            commit_dict[commit_type["group"]] = []
-
-                        # remove the commit tag from commit message
-                        cleaned_msg = (
-                            commit[1].replace(match.group(0), "").strip()
-                        )
-                        commit_dict[commit_type["group"]].append(
-                            f"{cleaned_msg} [{commit[0]}]"
-                            f"({commit_link}{commit[0]})"
-                        )
-
-        return commit_dict
-
     def _build_changelog(
         self,
         last_version: Optional[SupportsStr],
         next_version: Optional[SupportsStr],
-        commit_dict: Dict[str, List[str]],
+        commit_dict: dict[str, list[CommitLogEntry]],
     ) -> str:
         """
         Building the changelog from the passed commit information.
@@ -254,29 +318,34 @@ class ChangelogBuilder:
             changelog.append("## [Unreleased]")
 
         # changelog entries
-        commit_types = self.config.get("commit_types")
-        for commit_type in commit_types:
+        for commit_type in self._conventional_commits.commit_types():
             if commit_type["group"] in commit_dict.keys():
                 changelog.append(f"\n## {commit_type['group']}")
-                for msg in commit_dict[commit_type["group"]]:
+                for log_entry in commit_dict[commit_type["group"]]:
+                    commit_id, commit_message = log_entry
+                    commit_link = (
+                        f"{ADDRESS}{self._space}/{self._project}/"
+                        f"commit/{commit_id}"
+                    )
+                    msg = f"{commit_message} [{commit_id}]({commit_link})"
                     changelog.append(f"* {msg}")
 
         # comparison line (footer)
         pre = "\n[Unreleased]: "
-        compare_link = f"{ADDRESS}{self.space}/{self.project}/compare/"
+        compare_link = f"{ADDRESS}{self._space}/{self._project}/compare/"
         if next_version and last_version:
             pre = f"\n[{next_version}]: "
             diff = (
-                f"{self.git_tag_prefix}{last_version}..."
-                f"{self.git_tag_prefix}{next_version}"
+                f"{self._git_tag_prefix}{last_version}..."
+                f"{self._git_tag_prefix}{next_version}"
             )
         elif next_version:
             first_commit = self._get_first_commit()
             pre = f"\n[{next_version}]: "
-            diff = f"{first_commit}...{self.git_tag_prefix}{next_version}"
+            diff = f"{first_commit}...{self._git_tag_prefix}{next_version}"
         elif last_version:
             # unreleased version
-            diff = f"{self.git_tag_prefix}{last_version}...HEAD"
+            diff = f"{self._git_tag_prefix}{last_version}...HEAD"
         else:
             # unreleased version
             first_commit = self._get_first_commit()
