@@ -19,7 +19,15 @@ import subprocess
 from enum import Enum
 from os import PathLike, fspath
 from pathlib import Path
-from typing import Iterable, Iterator, List, Optional, Union
+from typing import (
+    Collection,
+    Iterable,
+    Iterator,
+    List,
+    Optional,
+    Sequence,
+    Union,
+)
 
 from pontos.errors import PontosError
 from pontos.git.status import StatusEntry, parse_git_status
@@ -168,6 +176,14 @@ class Git:
         """
         self._cwd = cwd.absolute()
 
+    @property
+    def version(self) -> str:
+        """
+        Get the version string of the installed git
+        """
+        # git --version returns "git version 2.3.4"
+        return self.exec("--version").strip().rsplit(" ", 1)[1]
+
     def exec(self, *args: str) -> str:
         return exec_git(*args, cwd=self._cwd)
 
@@ -374,14 +390,17 @@ class Git:
 
         return self.exec(*args).splitlines()
 
-    def add(self, files: Union[PathLike, List[PathLike]]) -> None:
+    def add(
+        self,
+        files: Union[str, PathLike[str], Sequence[Union[PathLike[str], str]]],
+    ) -> None:
         """
         Add files to the git staging area
 
         Args:
             files: A single file or a list of files to add to the staging area
         """
-        if isinstance(files, (PathLike, str, bytes)):
+        if isinstance(files, (PathLike, str)):
             files = [files]
 
         args = ["add"]
@@ -394,6 +413,7 @@ class Git:
         message: str,
         *,
         verify: Optional[bool] = None,
+        gpg_sign: Optional[bool] = None,
         gpg_signing_key: Optional[str] = None,
     ) -> None:
         """
@@ -402,6 +422,7 @@ class Git:
         Args:
             message: Message of the commit
             verify: Set to False to skip git hooks
+            gpg_sign: Set to False to skip signing the commit via GPG
             gpg_signing_key: GPG Key ID to use to sign the commit
         """
         args = ["commit"]
@@ -409,6 +430,8 @@ class Git:
             args.append("--no-verify")
         if gpg_signing_key:
             args.append(f"-S{gpg_signing_key}")
+        if gpg_sign is False:
+            args.append("--no-gpg-sign")
 
         args.extend(["-m", message])
 
@@ -421,6 +444,7 @@ class Git:
         gpg_key_id: Optional[str] = None,
         message: Optional[str] = None,
         force: Optional[bool] = False,
+        sign: Optional[bool] = None,
     ) -> None:
         """
         Create a Tag
@@ -430,6 +454,7 @@ class Git:
             gpg_key_id: GPG Key to sign the tag.
             message: Use message to annotate the given tag.
             force: True to replace an existing tag.
+            sign: Set to False to deactivate signing of the tag.
         """
         args = ["tag"]
 
@@ -442,6 +467,9 @@ class Git:
         if force:
             args.append("--force")
 
+        if sign is False:
+            args.append("--no-sign")
+
         args.append(tag)
 
         self.exec(*args)
@@ -516,16 +544,26 @@ class Git:
 
         self.exec(*args)
 
-    def log(self, *log_args: str, oneline: Optional[bool] = None) -> List[str]:
+    def log(
+        self,
+        *log_args: str,
+        oneline: Optional[bool] = None,
+        format: Optional[str] = None,
+    ) -> List[str]:
         """
         Get log of a git repository
 
         Args:
+            format: Pretty format the output.
             log_args: Additional arguments for git log
             oneline: Print the abbreviated commit id and commit message in one
                 line per commit
         """
         args = ["log"]
+
+        if format:
+            args.append(f"--format={format}")
+
         if oneline:
             args.append("--oneline")
 
@@ -533,6 +571,55 @@ class Git:
 
         return self.exec(*args).splitlines()
 
+    def show(
+        self,
+        *show_args: str,
+        format: Optional[str] = None,
+        oneline: Optional[bool] = None,
+        patch: Optional[bool] = None,
+        objects: Union[str, Collection[str], None] = None,
+    ) -> Union[str, list[str]]:
+        """
+        Show various types of git objects
+
+        Args:
+            format: Pretty format the output.
+            oneline: Print the abbreviated commit id and commit message in one
+                line per commit.
+            patch: True to generate patch output. False to suppress diff output.
+            show_args: Additional arguments for git show
+            objects: Git objects (commits, refs, ...) to get details for.
+
+        Returns:
+            A list of details about the passed object the object if more then
+            one object is passed. Otherwise a single details is returned.
+        """
+        args = ["show"]
+
+        if format:
+            args.append(f"--format={format}")
+
+        if oneline:
+            args.append("--oneline")
+
+        if patch is not None:
+            if patch:
+                args.append("--patch")
+            else:
+                args.append("--no-patch")
+
+        if objects:
+            if isinstance(objects, str):
+                objects = [objects]
+
+            args.extend(objects)
+
+        args.extend(show_args)
+
+        output = self.exec(*args).strip()
+
+        return output.splitlines() if objects and len(objects) > 1 else output
+
     def rev_list(
         self,
         *commit: str,
@@ -582,13 +669,13 @@ class Git:
         """
         Move a file from old to new
         """
-        return self.exec("mv", fspath(old), fspath(new))
+        self.exec("mv", fspath(old), fspath(new))
 
     def remove(self, to_remove: PathLike) -> None:
         """
         Remove a file from git
         """
-        return self.exec("rm", fspath(to_remove))
+        self.exec("rm", fspath(to_remove))
 
     def status(
         self,
