@@ -22,9 +22,12 @@ from typing import Optional, Type
 import httpx
 
 from pontos.github.api.artifacts import GitHubAsyncRESTArtifacts
+from pontos.github.api.billing import GitHubAsyncRESTBilling
 from pontos.github.api.branch import GitHubAsyncRESTBranches
 from pontos.github.api.client import GitHubAsyncRESTClient
+from pontos.github.api.code_scanning import GitHubAsyncRESTCodeScanning
 from pontos.github.api.contents import GitHubAsyncRESTContent
+from pontos.github.api.dependabot import GitHubAsyncRESTDependabot
 from pontos.github.api.helper import (
     DEFAULT_GITHUB_API_URL,
     DEFAULT_TIMEOUT_CONFIG,
@@ -35,8 +38,10 @@ from pontos.github.api.pull_requests import GitHubAsyncRESTPullRequests
 from pontos.github.api.release import GitHubAsyncRESTReleases
 from pontos.github.api.repositories import GitHubAsyncRESTRepositories
 from pontos.github.api.search import GitHubAsyncRESTSearch
+from pontos.github.api.secret_scanning import GitHubAsyncRESTSecretScanning
 from pontos.github.api.tags import GitHubAsyncRESTTags
 from pontos.github.api.teams import GitHubAsyncRESTTeams
+from pontos.github.api.users import GitHubAsyncRESTUsers
 from pontos.github.api.workflows import GitHubAsyncRESTWorkflows
 from pontos.helper import deprecated
 
@@ -85,6 +90,13 @@ class GitHubAsyncRESTApi(AbstractAsyncContextManager):
         """
         return GitHubAsyncRESTArtifacts(self._client)
 
+    @property
+    def billing(self) -> GitHubAsyncRESTBilling:
+        """
+        Billing related API
+        """
+        return GitHubAsyncRESTBilling(self._client)
+
     @property
     def branches(self) -> GitHubAsyncRESTBranches:
         """
@@ -92,6 +104,13 @@ class GitHubAsyncRESTApi(AbstractAsyncContextManager):
         """
         return GitHubAsyncRESTBranches(self._client)
 
+    @property
+    def code_scanning(self) -> GitHubAsyncRESTCodeScanning:
+        """
+        Code scanning related API
+        """
+        return GitHubAsyncRESTCodeScanning(self._client)
+
     @property
     def contents(self) -> GitHubAsyncRESTContent:
         """
@@ -99,6 +118,13 @@ class GitHubAsyncRESTApi(AbstractAsyncContextManager):
         """
         return GitHubAsyncRESTContent(self._client)
 
+    @property
+    def dependabot(self) -> GitHubAsyncRESTDependabot:
+        """
+        Dependabot related API
+        """
+        return GitHubAsyncRESTDependabot(self._client)
+
     @property
     def labels(self) -> GitHubAsyncRESTLabels:
         """
@@ -150,6 +176,20 @@ class GitHubAsyncRESTApi(AbstractAsyncContextManager):
         """
         return GitHubAsyncRESTRepositories(self._client)
 
+    @property
+    def secret_scanning(self) -> GitHubAsyncRESTSecretScanning:
+        """
+        Secret scanning related API
+        """
+        return GitHubAsyncRESTSecretScanning(self._client)
+
+    @property
+    def search(self) -> GitHubAsyncRESTSearch:
+        """
+        Search related API
+        """
+        return GitHubAsyncRESTSearch(self._client)
+
     @property
     def teams(self) -> GitHubAsyncRESTTeams:
         """
@@ -165,11 +205,11 @@ class GitHubAsyncRESTApi(AbstractAsyncContextManager):
         return GitHubAsyncRESTTags(self._client)
 
     @property
-    def search(self) -> GitHubAsyncRESTSearch:
+    def users(self) -> GitHubAsyncRESTUsers:
         """
-        Search related API
+        Users related API
         """
-        return GitHubAsyncRESTSearch(self._client)
+        return GitHubAsyncRESTUsers(self._client)
 
     async def __aenter__(self) -> "GitHubAsyncRESTApi":
         await self._client.__aenter__()
