@@ -18,17 +18,12 @@
 from dataclasses import dataclass
 from datetime import date, datetime
 from inspect import isclass
-from typing import Any, Dict, Type, Union, get_type_hints
+from typing import Any, Dict, Type, Union, get_args, get_origin, get_type_hints
 
 from dateutil import parser as dateparser
 
 from pontos.errors import PontosError
 
-try:
-    from typing import get_args, get_origin
-except ImportError:
-    from typing_extensions import get_args, get_origin
-
 __all__ = (
     "Model",
     "ModelError",
@@ -62,7 +57,7 @@ def dotted_attributes(obj: Any, data: Dict[str, Any]) -> Any:
         if isinstance(value, dict):
             default = None if hasattr(obj, key) else ModelAttribute()
             prop = getattr(obj, key, default)
-            value = dotted_attributes(prop, value)
+            value = dotted_attributes(prop, value)  # noqa: PLW2901
 
         setattr(obj, key, value)
 
@@ -155,6 +150,12 @@ class Model:
                     "updated_at": "2017-07-08T16:18:44-04:00",
                 })
         """
+        if not isinstance(data, dict):
+            raise ValueError(
+                f"Invalid data for creating an instance of {cls.__name__} "
+                f"model. Data is {data!r}"
+            )
+
         kwargs = {}
         additional_attrs = {}
         type_hints = get_type_hints(cls)
@@ -162,14 +163,14 @@ class Model:
             try:
                 if isinstance(value, list):
                     model_field_cls = type_hints.get(name)
-                    value = [cls._get_value(model_field_cls, v) for v in value]  # type: ignore # pylint: disable=line-too-long # noqa: E501
+                    value = [cls._get_value(model_field_cls, v) for v in value]  # type: ignore # pylint: disable=line-too-long # noqa: E501,PLW2901
                 elif value is not None:
                     model_field_cls = type_hints.get(name)
-                    value = cls._get_value(model_field_cls, value)  # type: ignore # pylint: disable=line-too-long # noqa: E501
-            except TypeError as e:
+                    value = cls._get_value(model_field_cls, value)  # type: ignore # pylint: disable=line-too-long # noqa: E501,PLW2901
+            except (ValueError, TypeError) as e:
                 raise ModelError(
-                    f"Error while creating {cls.__name__}. Could not set value "
-                    f"for '{name}' from '{value}'."
+                    f"Error while creating {cls.__name__} model. Could not set "
+                    f"value for property '{name}' from '{value}'."
                 ) from e
 
             if name in type_hints:
