@@ -17,6 +17,7 @@
 
 import asyncio
 from argparse import ArgumentParser, Namespace
+from typing import Callable
 
 from pontos.nvd.cpe.api import CPEApi
 
@@ -64,7 +65,7 @@ def cpes_main() -> None:
     main(parser, query_cpes)
 
 
-def main(parser: ArgumentParser, func: callable) -> None:
+def main(parser: ArgumentParser, func: Callable) -> None:
     try:
         args = parser.parse_args()
         asyncio.run(func(args))
