@@ -16,17 +16,17 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
+from .create import CreateReleaseCommand, CreateReleaseReturnValue
 from .helper import ReleaseType, find_signing_key, get_git_repository_name
 from .main import main
-from .release import ReleaseCommand, ReleaseReturnValue
 from .sign import SignatureError, SignCommand, SignReturnValue
 
 __all__ = (
     "ReleaseType",
     "get_git_repository_name",
     "find_signing_key",
-    "ReleaseCommand",
-    "ReleaseReturnValue",
+    "CreateReleaseCommand",
+    "CreateReleaseReturnValue",
     "SignCommand",
     "SignatureError",
     "SignReturnValue",
