@@ -18,6 +18,7 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #
 
+import logging
 import subprocess
 import sys
 from typing import NoReturn
@@ -32,37 +33,40 @@ def main(
     args=None,
 ) -> NoReturn:
     username, token, parsed_args = parse_args(args)
+    logging.basicConfig(format="%(levelname)s - %(name)s - %(message)s")
+
     if parsed_args.quiet:
         term = NullTerminal()
+        error_terminal = NullTerminal()
+        logging.disable()
     else:
-        term = RichTerminal()
+        term = RichTerminal()  # type: ignore[assignment]
+        error_terminal = RichTerminal(file=sys.stderr)  # type: ignore[assignment] # noqa: E501
 
-    term.bold_info(f"pontos-release => {parsed_args.func.__name__}")
+    try:
+        retval = parsed_args.func(
+            parsed_args,
+            terminal=term,
+            error_terminal=error_terminal,
+            username=username,
+            token=token,
+        )
+        sys.exit(int(retval))
+    except KeyboardInterrupt:
+        sys.exit(1)
+    except GitError as e:
+        error_terminal.error(f'Could not run git command "{e.cmd}".')
+        error = e.stderr if e.stderr else e.stdout
+        error_terminal.print(f"Output was: {error}")
+        sys.exit(1)
+    except subprocess.CalledProcessError as e:
+        if "--passphrase" not in e.cmd:
+            error_terminal.error(f'Could not run command "{e.cmd}".')
+        else:
+            error_terminal.error("Headless signing failed.")
 
-    with term.indent():
-        try:
-            retval = parsed_args.func(
-                term,
-                parsed_args,
-                username=username,
-                token=token,
-            )
-            sys.exit(int(retval))
-        except KeyboardInterrupt:
-            sys.exit(1)
-        except GitError as e:
-            term.error(f'Could not run git command "{e.cmd}".')
-            error = e.stderr if e.stderr else e.stdout
-            term.print(f"Output was: {error}")
-            sys.exit(1)
-        except subprocess.CalledProcessError as e:
-            if "--passphrase" not in e.cmd:
-                term.error(f'Could not run command "{e.cmd}".')
-            else:
-                term.error("Headless signing failed.")
-
-            term.print(f"Error was: {e.stderr}")
-            sys.exit(1)
+        error_terminal.print(f"Error was: {e.stderr}")
+        sys.exit(1)
 
 
 if __name__ == "__main__":
