@@ -25,22 +25,24 @@ from argparse import (
 )
 from enum import Enum
 from pathlib import Path
-from typing import Callable, Tuple, Type
+from typing import Callable, Optional, Tuple, Type
 
 from pontos.release.helper import ReleaseType
+from pontos.release.show import OutputFormat, show
 from pontos.version.schemes import (
     VERSIONING_SCHEMES,
+    PEP440VersioningScheme,
     VersioningScheme,
     versioning_scheme_argument_type,
 )
 
-from .release import release
+from .create import create_release
 from .sign import sign
 
 DEFAULT_SIGNING_KEY = "0ED1E580"
 
 
-def to_choices(enum: Type[Enum]) -> list[str]:
+def to_choices(enum: Type[Enum]) -> str:
     return ", ".join([t.value for t in enum])
 
 
@@ -64,7 +66,7 @@ class ReleaseVersionAction(
         setattr(namespace, self.dest, values)
 
 
-def parse_args(args) -> Tuple[str, str, Namespace]:
+def parse_args(args) -> Tuple[Optional[str], Optional[str], Namespace]:
     """
     Return user, token, parsed arguments
     """
@@ -88,9 +90,11 @@ def parse_args(args) -> Tuple[str, str, Namespace]:
         required=True,
     )
 
-    release_parser = subparsers.add_parser("release")
-    release_parser.set_defaults(func=release)
-    release_parser.add_argument(
+    create_parser = subparsers.add_parser(
+        "create", help="Create a new release", aliases=["release"]
+    )
+    create_parser.set_defaults(func=create_release)
+    create_parser.add_argument(
         "--versioning-scheme",
         help="Versioning scheme to use for parsing and handling version "
         f"information. Choices are {', '.join(VERSIONING_SCHEMES.keys())}. "
@@ -98,13 +102,13 @@ def parse_args(args) -> Tuple[str, str, Namespace]:
         default="pep440",
         type=versioning_scheme_argument_type,
     )
-    release_parser.add_argument(
+    create_parser.add_argument(
         "--release-type",
         help="Select the release type for calculating the release version. "
         f"Possible choices are: {to_choices(ReleaseType)}.",
         type=enum_type(ReleaseType),
     )
-    release_parser.add_argument(
+    create_parser.add_argument(
         "--release-version",
         help=(
             "Will release changelog as version. "
@@ -112,14 +116,16 @@ def parse_args(args) -> Tuple[str, str, Namespace]:
         ),
         action=ReleaseVersionAction,
     )
-    release_parser.add_argument(
+    create_parser.add_argument(
         "--release-series",
         help="Create a release for a release series. Setting a release series "
         "is required if the latest tag version is newer then the to be "
         'released version. Examples: "1.2", "2", "22.4"',
     )
 
-    release_parser.add_argument(
+    next_version_group = create_parser.add_mutually_exclusive_group()
+
+    next_version_group.add_argument(
         "--next-version",
         help=(
             "Sets the next version in project definition "
@@ -127,51 +133,67 @@ def parse_args(args) -> Tuple[str, str, Namespace]:
         ),
     )
 
-    release_parser.add_argument(
+    next_version_group.add_argument(
+        "--no-next-version",
+        help="Don't set a next version after the release.",
+        dest="next_version",
+        action="store_false",
+    )
+
+    create_parser.add_argument(
         "--git-remote-name",
         help="The git remote name to push the commits and tag to",
     )
-    release_parser.add_argument(
+    create_parser.add_argument(
         "--git-tag-prefix",
         default="v",
+        const="",
+        nargs="?",
         help="Prefix for git tag versions. Default: %(default)s",
     )
-    release_parser.add_argument(
+    create_parser.add_argument(
         "--git-signing-key",
         help="The key to sign the commits and tag for a release",
         default=os.environ.get("GPG_SIGNING_KEY"),
     )
-    release_parser.add_argument(
+    create_parser.add_argument(
         "--project",
         help="The github project",
     )
-    release_parser.add_argument(
+    create_parser.add_argument(
         "--space",
         default="greenbone",
         help="User/Team name in github",
     )
-    release_parser.add_argument(
+    create_parser.add_argument(
         "--local",
         action="store_true",
         help="Only create release changes locally and do not upload them to a "
         "remote repository. Also do not create a GitHub release.",
     )
-    release_parser.add_argument(
+    create_parser.add_argument(
         "--conventional-commits-config",
         dest="cc_config",
         type=Path,
         help="Conventional commits config file (toml), including conventions."
         " If not set defaults are used.",
     )
-    release_parser.add_argument(
+    create_parser.add_argument(
         "--update-project",
         help="Update version in project files like pyproject.toml. By default "
         "project files are updated.",
         action=BooleanOptionalAction,
         default=True,
     )
+    create_parser.add_argument(
+        "--github-pre-release",
+        help="Enforce uploading a release as GitHub pre-release. ",
+        action="store_true",
+    )
 
-    sign_parser = subparsers.add_parser("sign")
+    sign_parser = subparsers.add_parser(
+        "sign", help="Create signatures for an existing release"
+    )
     sign_parser.set_defaults(func=sign)
     sign_parser.add_argument(
         "--signing-key",
@@ -199,6 +221,8 @@ def parse_args(args) -> Tuple[str, str, Namespace]:
     sign_parser.add_argument(
         "--git-tag-prefix",
         default="v",
+        const="",
+        nargs="?",
         help="Prefix for git tag versions. Default: %(default)s",
     )
     sign_parser.add_argument(
@@ -221,11 +245,62 @@ def parse_args(args) -> Tuple[str, str, Namespace]:
     sign_parser.add_argument(
         "--dry-run", action="store_true", help="Do not upload signed files."
     )
+
+    show_parser = subparsers.add_parser(
+        "show",
+        help="Show release information about the current release version and "
+        "determine the next release version",
+    )
+    show_parser.set_defaults(func=show)
+    show_parser.add_argument(
+        "--versioning-scheme",
+        help="Versioning scheme to use for parsing and handling version "
+        f"information. Choices are {', '.join(VERSIONING_SCHEMES.keys())}. "
+        "Default: %(default)s",
+        default="pep440",
+        type=versioning_scheme_argument_type,
+    )
+    show_parser.add_argument(
+        "--release-type",
+        help="Select the release type for calculating the release version. "
+        f"Possible choices are: {to_choices(ReleaseType)}.",
+        type=enum_type(ReleaseType),
+    )
+    show_parser.add_argument(
+        "--release-version",
+        help=(
+            "Will release changelog as version. "
+            "Default: lookup version in project definition."
+        ),
+        action=ReleaseVersionAction,
+    )
+    show_parser.add_argument(
+        "--release-series",
+        help="Create a release for a release series. Setting a release series "
+        "is required if the latest tag version is newer then the to be "
+        'released version. Examples: "1.2", "2", "22.4"',
+    )
+    show_parser.add_argument(
+        "--git-tag-prefix",
+        default="v",
+        const="",
+        nargs="?",
+        help="Prefix for git tag versions. Default: %(default)s",
+    )
+    show_parser.add_argument(
+        "--output-format",
+        help="Print in the desired output format. "
+        f"Possible choices are: {to_choices(OutputFormat)}.",
+        type=enum_type(OutputFormat),
+    )
+
     parsed_args = parser.parse_args(args)
 
-    scheme: VersioningScheme = getattr(parsed_args, "versioning_scheme", None)
+    scheme: type[VersioningScheme] = getattr(
+        parsed_args, "versioning_scheme", PEP440VersioningScheme
+    )
 
-    if parsed_args.func in (release,):
+    if parsed_args.func in (create_release, show):
         # check for release-type
         if not getattr(parsed_args, "release_type", None):
             parser.error("--release-type is required.")
