@@ -1,4 +1,4 @@
-# Copyright (C) 2020-2022 Greenbone Networks GmbH
+# Copyright (C) 2020-2022 Greenbone AG
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
 #
@@ -17,7 +17,7 @@
 
 # pylint: disable=invalid-name
 
-from pontos import version
+from .main import main
 
 if __name__ == "__main__":
-    version.main()
+    main()
