@@ -111,17 +111,17 @@ class PEP440Version(Version):
     @property
     def is_alpha_release(self) -> bool:
         """Whether this version is a alpha release."""
-        return self.is_pre_release and self.pre and self.pre[0] == "alpha"
+        return bool(self.is_pre_release and self.pre and self.pre[0] == "alpha")
 
     @property
     def is_beta_release(self) -> bool:
         """Whether this version is a beta release."""
-        return self.is_pre_release and self.pre and self.pre[0] == "beta"
+        return bool(self.is_pre_release and self.pre and self.pre[0] == "beta")
 
     @property
     def is_release_candidate(self) -> bool:
         """Whether this version is a release candidate."""
-        return self.is_pre_release and self.pre and self.pre[0] == "rc"
+        return bool(self.is_pre_release and self.pre and self.pre[0] == "rc")
 
     @classmethod
     def from_string(cls, version: str) -> "PEP440Version":
@@ -185,7 +185,7 @@ class PEP440Version(Version):
                 f"{version.major}."
                 f"{version.minor}."
                 f"{version.patch}"
-                f"-{version.pre[0]}{version.pre[1]}"
+                f"-{version.pre[0]}{version.pre[1]}"  # type: ignore[index]
                 f"{version_local}"
             )
         else:
@@ -225,6 +225,27 @@ class PEP440Version(Version):
             other = self.from_version(other)
         return self._version > other._version
 
+    def __ge__(self, other: Any) -> bool:
+        if not isinstance(other, Version):
+            raise ValueError(f"Can't compare {type(self)} with {type(other)}")
+        if not isinstance(other, type(self)):
+            other = self.from_version(other)
+        return self._version >= other._version
+
+    def __lt__(self, other: Any) -> bool:
+        if not isinstance(other, Version):
+            raise ValueError(f"Can't compare {type(self)} with {type(other)}")
+        if not isinstance(other, type(self)):
+            other = self.from_version(other)
+        return self._version < other._version
+
+    def __le__(self, other: Any) -> bool:
+        if not isinstance(other, Version):
+            raise ValueError(f"Can't compare {type(self)} with {type(other)}")
+        if not isinstance(other, type(self)):
+            other = self.from_version(other)
+        return self._version <= other._version
+
     def __str__(self) -> str:
         return str(self._version)
 
@@ -248,17 +269,17 @@ class PEP440VersionCalculator(VersionCalculator):
         if current_version.is_dev_release:
             if current_version.pre:
                 return cls.version_from_string(
-                    f"{current_version.major}."
+                    f"{current_version.major}."  # type: ignore[operator]
                     f"{current_version.minor}."
                     f"{current_version.patch}"
-                    f"-{current_version.pre[0]}{current_version.pre[1]}"
-                    f".dev{current_version.dev + 1}"
+                    f"-{current_version.pre[0]}{current_version.pre[1]}"  # type: ignore[index] # noqa: E501
+                    f".dev{current_version.dev + 1}"  # type: ignore[operator]
                 )
             return cls.version_from_string(
-                f"{current_version.major}."
+                f"{current_version.major}."  # type: ignore[operator]
                 f"{current_version.minor}."
                 f"{current_version.patch}"
-                f".dev{current_version.dev + 1}"
+                f".dev{current_version.dev + 1}"  # type: ignore[operator]
             )
 
         if current_version.is_pre_release:
@@ -266,7 +287,7 @@ class PEP440VersionCalculator(VersionCalculator):
                 f"{current_version.major}."
                 f"{current_version.minor}."
                 f"{current_version.patch}"
-                f"{current_version.pre[0]}{current_version.pre[1] + 1}.dev1"
+                f"{current_version.pre[0]}{current_version.pre[1] + 1}.dev1"  # type: ignore[index] # noqa: E501
             )
 
         return cls.version_from_string(
@@ -308,7 +329,7 @@ class PEP440VersionCalculator(VersionCalculator):
             return cls.version_from_string(
                 f"{current_version.major}."
                 f"{current_version.minor}."
-                f"{current_version.patch}a{current_version.pre[1] + 1}"
+                f"{current_version.patch}a{current_version.pre[1] + 1}"  # type: ignore[index] # noqa: E501
             )
 
         return cls.version_from_string(
@@ -352,7 +373,7 @@ class PEP440VersionCalculator(VersionCalculator):
                 f"{current_version.major}."
                 f"{current_version.minor}."
                 f"{current_version.patch}"
-                f"b{current_version.pre[1] + 1}"
+                f"b{current_version.pre[1] + 1}"  # type: ignore[index]
             )
         return cls.version_from_string(
             f"{current_version.major}."
@@ -396,7 +417,7 @@ class PEP440VersionCalculator(VersionCalculator):
             return cls.version_from_string(
                 f"{current_version.major}."
                 f"{current_version.minor}."
-                f"{current_version.patch}rc{current_version.pre[1] + 1}"
+                f"{current_version.patch}rc{current_version.pre[1] + 1}"  # type: ignore[index] # noqa: E501
             )
 
         return cls.version_from_string(
