@@ -17,7 +17,7 @@
 
 import unittest
 from pathlib import Path
-from unittest.mock import patch
+from unittest.mock import MagicMock, patch
 
 from pontos.git import Git
 from pontos.git.git import (
@@ -394,6 +394,15 @@ class GitTestCase(unittest.TestCase):
             "commit", "--no-verify", "-m", "Add foo", cwd=None
         )
 
+    @patch("pontos.git.git.exec_git")
+    def test_commit_without_gpg_sign(self, exec_git_mock):
+        git = Git()
+        git.commit("Add foo", gpg_sign=False)
+
+        exec_git_mock.assert_called_once_with(
+            "commit", "--no-gpg-sign", "-m", "Add foo", cwd=None
+        )
+
     @patch("pontos.git.git.exec_git")
     def test_tag(self, exec_git_mock):
         git = Git()
@@ -428,6 +437,15 @@ class GitTestCase(unittest.TestCase):
             "tag", "--force", "test", cwd=None
         )
 
+    @patch("pontos.git.git.exec_git")
+    def test_tag_without_sign(self, exec_git_mock):
+        git = Git()
+        git.tag("test", sign=False)
+
+        exec_git_mock.assert_called_once_with(
+            "tag", "--no-sign", "test", cwd=None
+        )
+
     @patch("pontos.git.git.exec_git")
     def test_fetch(self, exec_git_mock):
         git = Git()
@@ -556,6 +574,25 @@ e6ea80d Update README
         self.assertEqual(logs[0], "50f9963 Add CircleCI config for pontos")
         self.assertEqual(logs[5], "464f24d Initial commit")
 
+    @patch("pontos.git.git.exec_git")
+    def test_log_with_format(self, exec_git_mock):
+        exec_git_mock.return_value = """Add CircleCI config for pontos
+Rename to pontos only
+Update README for installation and development
+Update README
+Add a draft for a README.md document
+Initial commit"""
+
+        git = Git()
+        logs = git.log(format="format:%s")
+
+        exec_git_mock.assert_called_once_with(
+            "log", "--format=format:%s", cwd=None
+        )
+
+        self.assertEqual(logs[0], "Add CircleCI config for pontos")
+        self.assertEqual(logs[5], "Initial commit")
+
     @patch("pontos.git.git.exec_git")
     def test_rev_list(self, exec_git_mock):
         git = Git()
@@ -624,6 +661,114 @@ e6ea80d Update README
             cwd=None,
         )
 
+    @patch("pontos.git.git.exec_git")
+    def test_version(self, exec_git_mock: MagicMock):
+        exec_git_mock.return_value = "git version 1.2.3"
+        git = Git()
+        self.assertEqual(git.version, "1.2.3")
+
+    def test_version_runs(self):
+        """Getting the git version should not raise an error"""
+        git = Git()
+        git.version
+
+    @patch("pontos.git.git.exec_git")
+    def test_show_with_online_and_objects(self, exec_git_mock: MagicMock):
+        exec_git_mock.return_value = """9a8feaa Rename to pontos only
+047cfae Update README for installation and development
+"""
+
+        git = Git()
+        show = git.show(oneline=True, objects=["9a8feaa", "047cfae"])
+
+        exec_git_mock.assert_called_once_with(
+            "show", "--oneline", "9a8feaa", "047cfae", cwd=None
+        )
+
+        self.assertEqual(show[0], "9a8feaa Rename to pontos only")
+        self.assertEqual(
+            show[1], "047cfae Update README for installation and development"
+        )
+
+    @patch("pontos.git.git.exec_git")
+    def test_show_with_format(self, exec_git_mock: MagicMock):
+        exec_git_mock.return_value = """Rename to pontos only
+"""
+
+        git = Git()
+        show = git.show(format="format:%s")
+
+        exec_git_mock.assert_called_once_with(
+            "show", "--format=format:%s", cwd=None
+        )
+
+        self.assertEqual(show, "Rename to pontos only")
+
+    @patch("pontos.git.git.exec_git")
+    def test_show_with_single_object(self, exec_git_mock: MagicMock):
+        content = """commit a6956fb1398cae9426e7ced0396248a90dc1ff64
+Author: Björn Ricks <bjoern.ricks@greenbone.net>
+Date:   Wed Jul 19 15:07:03 2023 +0200
+
+    Add: Allow to get the git version string
+
+diff --git a/pontos/git/git.py b/pontos/git/git.py
+index a83eed8..09aed3d 100644
+--- a/pontos/git/git.py
++++ b/pontos/git/git.py
+@@ -168,6 +168,14 @@ class Git:
+...
+"""
+        exec_git_mock.return_value = content
+
+        git = Git()
+        show = git.show(objects="9a8feaa")
+
+        exec_git_mock.assert_called_once_with("show", "9a8feaa", cwd=None)
+
+        self.assertEqual(show, content.strip())
+
+    @patch("pontos.git.git.exec_git")
+    def test_show_with_patch(self, exec_git_mock: MagicMock):
+        content = """commit a6956fb1398cae9426e7ced0396248a90dc1ff64
+Author: Björn Ricks <bjoern.ricks@greenbone.net>
+Date:   Wed Jul 19 15:07:03 2023 +0200
+
+    Add: Allow to get the git version string
+
+diff --git a/pontos/git/git.py b/pontos/git/git.py
+index a83eed8..09aed3d 100644
+--- a/pontos/git/git.py
++++ b/pontos/git/git.py
+@@ -168,6 +168,14 @@ class Git:
+...
+"""
+        exec_git_mock.return_value = content
+
+        git = Git()
+        show = git.show(patch=True)
+
+        exec_git_mock.assert_called_once_with("show", "--patch", cwd=None)
+
+        self.assertEqual(show, content.strip())
+
+    @patch("pontos.git.git.exec_git")
+    def test_show_with_no_patch(self, exec_git_mock: MagicMock):
+        content = """commit a6956fb1398cae9426e7ced0396248a90dc1ff64
+Author: Björn Ricks <bjoern.ricks@greenbone.net>
+Date:   Wed Jul 19 15:07:03 2023 +0200
+
+    Add: Allow to get the git version string
+"""
+        exec_git_mock.return_value = content
+
+        git = Git()
+        show = git.show(patch=False)
+
+        exec_git_mock.assert_called_once_with("show", "--no-patch", cwd=None)
+
+        self.assertEqual(show, content.strip())
+
 
 class GitExtendedTestCase(unittest.TestCase):
     def test_semantic_list_tags(self):
