@@ -773,3 +773,37 @@ class GitHubAsyncRESTRepositoriesTestCase(GitHubAsyncRESTTestCase):
                 "web_commit_signoff_required": False,
             },
         )
+
+    async def test_get_topics(self):
+        response = create_response()
+        response.json.return_value = {"names": ["foo", "bar", "baz"]}
+        self.client.get.return_value = response
+
+        topics = await self.api.topics("foo/bar")
+
+        self.client.get.assert_awaited_once_with("/repos/foo/bar/topics")
+
+        self.assertEqual(len(topics), 3)
+        self.assertEqual(topics, ["foo", "bar", "baz"])
+
+    async def test_update_topics(self):
+        response = create_response()
+        response.json.return_value = {}
+        response.json.return_value = {"names": ["foo", "bar"]}
+
+        self.client.put.return_value = response
+
+        new_topics = await self.api.update_topics(
+            "foo/bar",
+            (
+                "foo",
+                "bar",
+            ),
+        )
+
+        self.client.put.assert_awaited_once_with(
+            "/repos/foo/bar/topics", data={"names": ["foo", "bar"]}
+        )
+
+        self.assertEqual(len(new_topics), 2)
+        self.assertEqual(new_topics, ["foo", "bar"])
