@@ -25,18 +25,24 @@ from unittest.mock import MagicMock, patch
 from httpx import AsyncClient, Response
 
 from pontos.errors import PontosError
-from pontos.nvd.api import now, sleep
-from pontos.nvd.cpe.api import CPEApi
+from pontos.nvd.api import now
+from pontos.nvd.cpe.api import MAX_CPES_PER_PAGE, CPEApi
 from tests import AsyncMock, IsolatedAsyncioTestCase, aiter, anext
 from tests.nvd import get_cpe_data
 
 
 def create_cpe_response(
-    cpe_name_id: str, update: Optional[Dict[str, Any]] = None
+    cpe_name_id: str,
+    *,
+    update: Optional[Dict[str, Any]] = None,
+    results: int = 1,
 ) -> MagicMock:
     data = {
-        "products": [{"cpe": get_cpe_data({"cpe_name_id": cpe_name_id})}],
-        "results_per_page": 1,
+        "products": [
+            {"cpe": get_cpe_data({"cpe_name_id": f"{cpe_name_id}-{i}"})}
+            for i in range(1, results + 1)
+        ],
+        "results_per_page": results,
     }
     if update:
         data.update(update)
@@ -46,18 +52,26 @@ def create_cpe_response(
     return response
 
 
-def create_cpes_responses(count: int = 2) -> List[MagicMock]:
+def create_cpes_responses(
+    responses: int = 2, results_per_response: int = 1
+) -> List[MagicMock]:
     return [
-        create_cpe_response(f"CPE-{i}", {"total_results": count})
-        for i in range(1, count + 1)
+        create_cpe_response(
+            cpe_name_id=f"CPE-{i}",
+            update={"total_results": responses * results_per_response},
+            results=results_per_response,
+        )
+        for i in range(1, responses + 1)
     ]
 
 
 class CPEApiTestCase(IsolatedAsyncioTestCase):
+    @patch("pontos.nvd.api.time.monotonic", autospec=True)
     @patch("pontos.nvd.api.AsyncClient", spec=AsyncClient)
-    def setUp(self, async_client: MagicMock) -> None:
+    def setUp(self, async_client: MagicMock, monotonic_mock: MagicMock) -> None:
         self.http_client = AsyncMock()
         async_client.return_value = self.http_client
+        monotonic_mock.return_value = 0
         self.api = CPEApi()
 
     async def test_no_cpe_name_id(self):
@@ -79,19 +93,19 @@ class CPEApiTestCase(IsolatedAsyncioTestCase):
     async def test_cpe(self):
         self.http_client.get.return_value = create_cpe_response("CPE-1")
 
-        cpe = await self.api.cpe("CPE-1")
+        cpe = await self.api.cpe("CPE-1-1")
 
         self.http_client.get.assert_awaited_once_with(
             "https://services.nvd.nist.gov/rest/json/cpes/2.0",
             headers={},
-            params={"cpeNameId": "CPE-1"},
+            params={"cpeNameId": "CPE-1-1"},
         )
 
         self.assertEqual(
             cpe.cpe_name,
             "cpe:2.3:o:microsoft:windows_10_22h2:-:*:*:*:*:*:arm64:*",
         )
-        self.assertEqual(cpe.cpe_name_id, "CPE-1")
+        self.assertEqual(cpe.cpe_name_id, "CPE-1-1")
         self.assertFalse(cpe.deprecated)
         self.assertEqual(
             cpe.last_modified, datetime(2022, 12, 9, 18, 15, 16, 973000)
@@ -102,9 +116,15 @@ class CPEApiTestCase(IsolatedAsyncioTestCase):
         self.assertEqual(cpe.titles, [])
         self.assertEqual(cpe.deprecated_by, [])
 
-    @patch("pontos.nvd.api.sleep", spec=sleep)
-    async def test_rate_limit(self, sleep_mock: MagicMock):
-        self.http_client.get.side_effect = create_cpes_responses(6)
+    @patch("pontos.nvd.api.time.monotonic", autospec=True)
+    @patch("pontos.nvd.api.asyncio.sleep", autospec=True)
+    async def test_rate_limit(
+        self,
+        sleep_mock: MagicMock,
+        monotonic_mock: MagicMock,
+    ):
+        self.http_client.get.side_effect = create_cpes_responses(8)
+        monotonic_mock.side_effect = [10, 11]
 
         it = aiter(self.api.cpes())
         await anext(it)
@@ -117,7 +137,7 @@ class CPEApiTestCase(IsolatedAsyncioTestCase):
 
         await anext(it)
 
-        sleep_mock.assert_called_once_with()
+        sleep_mock.assert_called_once_with(20.0)
 
     @patch("pontos.nvd.cpe.api.now", spec=now)
     async def test_cves_last_modified_start_date(self, now_mock: MagicMock):
@@ -129,7 +149,7 @@ class CPEApiTestCase(IsolatedAsyncioTestCase):
         )
         cve = await anext(it)
 
-        self.assertEqual(cve.cpe_name_id, "CPE-1")
+        self.assertEqual(cve.cpe_name_id, "CPE-1-1")
         self.http_client.get.assert_awaited_once_with(
             "https://services.nvd.nist.gov/rest/json/cpes/2.0",
             headers={},
@@ -137,6 +157,7 @@ class CPEApiTestCase(IsolatedAsyncioTestCase):
                 "startIndex": 0,
                 "lastModStartDate": "2022-12-01T00:00:00",
                 "lastModEndDate": "2022-12-31T00:00:00",
+                "resultsPerPage": MAX_CPES_PER_PAGE,
             },
         )
 
@@ -144,7 +165,7 @@ class CPEApiTestCase(IsolatedAsyncioTestCase):
 
         cve = await anext(it)
 
-        self.assertEqual(cve.cpe_name_id, "CPE-2")
+        self.assertEqual(cve.cpe_name_id, "CPE-2-1")
         self.http_client.get.assert_awaited_once_with(
             "https://services.nvd.nist.gov/rest/json/cpes/2.0",
             headers={},
@@ -170,7 +191,7 @@ class CPEApiTestCase(IsolatedAsyncioTestCase):
         )
         cve = await anext(it)
 
-        self.assertEqual(cve.cpe_name_id, "CPE-1")
+        self.assertEqual(cve.cpe_name_id, "CPE-1-1")
         self.http_client.get.assert_awaited_once_with(
             "https://services.nvd.nist.gov/rest/json/cpes/2.0",
             headers={},
@@ -178,6 +199,7 @@ class CPEApiTestCase(IsolatedAsyncioTestCase):
                 "startIndex": 0,
                 "lastModStartDate": "2022-12-01T00:00:00",
                 "lastModEndDate": "2022-12-31T00:00:00",
+                "resultsPerPage": MAX_CPES_PER_PAGE,
             },
         )
 
@@ -185,7 +207,7 @@ class CPEApiTestCase(IsolatedAsyncioTestCase):
 
         cve = await anext(it)
 
-        self.assertEqual(cve.cpe_name_id, "CPE-2")
+        self.assertEqual(cve.cpe_name_id, "CPE-2-1")
         self.http_client.get.assert_awaited_once_with(
             "https://services.nvd.nist.gov/rest/json/cpes/2.0",
             headers={},
@@ -206,7 +228,7 @@ class CPEApiTestCase(IsolatedAsyncioTestCase):
         it = aiter(self.api.cpes(keywords=["Mac OS X", "kernel"]))
         cve = await anext(it)
 
-        self.assertEqual(cve.cpe_name_id, "CPE-1")
+        self.assertEqual(cve.cpe_name_id, "CPE-1-1")
         self.http_client.get.assert_awaited_once_with(
             "https://services.nvd.nist.gov/rest/json/cpes/2.0",
             headers={},
@@ -214,6 +236,7 @@ class CPEApiTestCase(IsolatedAsyncioTestCase):
                 "startIndex": 0,
                 "keywordSearch": "Mac OS X kernel",
                 "keywordExactMatch": "",
+                "resultsPerPage": MAX_CPES_PER_PAGE,
             },
         )
 
@@ -221,7 +244,7 @@ class CPEApiTestCase(IsolatedAsyncioTestCase):
 
         cve = await anext(it)
 
-        self.assertEqual(cve.cpe_name_id, "CPE-2")
+        self.assertEqual(cve.cpe_name_id, "CPE-2-1")
         self.http_client.get.assert_awaited_once_with(
             "https://services.nvd.nist.gov/rest/json/cpes/2.0",
             headers={},
@@ -242,13 +265,14 @@ class CPEApiTestCase(IsolatedAsyncioTestCase):
         it = aiter(self.api.cpes(keywords="macOS"))
         cve = await anext(it)
 
-        self.assertEqual(cve.cpe_name_id, "CPE-1")
+        self.assertEqual(cve.cpe_name_id, "CPE-1-1")
         self.http_client.get.assert_awaited_once_with(
             "https://services.nvd.nist.gov/rest/json/cpes/2.0",
             headers={},
             params={
                 "startIndex": 0,
                 "keywordSearch": "macOS",
+                "resultsPerPage": MAX_CPES_PER_PAGE,
             },
         )
 
@@ -256,7 +280,7 @@ class CPEApiTestCase(IsolatedAsyncioTestCase):
 
         cve = await anext(it)
 
-        self.assertEqual(cve.cpe_name_id, "CPE-2")
+        self.assertEqual(cve.cpe_name_id, "CPE-2-1")
         self.http_client.get.assert_awaited_once_with(
             "https://services.nvd.nist.gov/rest/json/cpes/2.0",
             headers={},
@@ -280,12 +304,13 @@ class CPEApiTestCase(IsolatedAsyncioTestCase):
         )
         cve = await anext(it)
 
-        self.assertEqual(cve.cpe_name_id, "CPE-1")
+        self.assertEqual(cve.cpe_name_id, "CPE-1-1")
         self.http_client.get.assert_awaited_once_with(
             "https://services.nvd.nist.gov/rest/json/cpes/2.0",
             headers={},
             params={
                 "startIndex": 0,
+                "resultsPerPage": MAX_CPES_PER_PAGE,
                 "cpeMatchString": "cpe:2.3:o:microsoft:windows_10:20h2:*:*:*:*:*:*:*",
             },
         )
@@ -294,7 +319,7 @@ class CPEApiTestCase(IsolatedAsyncioTestCase):
 
         cve = await anext(it)
 
-        self.assertEqual(cve.cpe_name_id, "CPE-2")
+        self.assertEqual(cve.cpe_name_id, "CPE-2-1")
         self.http_client.get.assert_awaited_once_with(
             "https://services.nvd.nist.gov/rest/json/cpes/2.0",
             headers={},
@@ -318,13 +343,14 @@ class CPEApiTestCase(IsolatedAsyncioTestCase):
         )
         cve = await anext(it)
 
-        self.assertEqual(cve.cpe_name_id, "CPE-1")
+        self.assertEqual(cve.cpe_name_id, "CPE-1-1")
         self.http_client.get.assert_awaited_once_with(
             "https://services.nvd.nist.gov/rest/json/cpes/2.0",
             headers={},
             params={
                 "startIndex": 0,
                 "matchCriteriaId": "36FBCF0F-8CEE-474C-8A04-5075AF53FAF4",
+                "resultsPerPage": MAX_CPES_PER_PAGE,
             },
         )
 
@@ -332,7 +358,7 @@ class CPEApiTestCase(IsolatedAsyncioTestCase):
 
         cve = await anext(it)
 
-        self.assertEqual(cve.cpe_name_id, "CPE-2")
+        self.assertEqual(cve.cpe_name_id, "CPE-2-1")
         self.http_client.get.assert_awaited_once_with(
             "https://services.nvd.nist.gov/rest/json/cpes/2.0",
             headers={},
@@ -346,6 +372,51 @@ class CPEApiTestCase(IsolatedAsyncioTestCase):
         with self.assertRaises(StopAsyncIteration):
             cve = await anext(it)
 
+    async def test_cpes_request_results(self):
+        self.http_client.get.side_effect = create_cpes_responses(
+            results_per_response=2
+        )
+
+        it = aiter(self.api.cpes(request_results=10))
+        cve = await anext(it)
+
+        self.http_client.get.assert_awaited_once_with(
+            "https://services.nvd.nist.gov/rest/json/cpes/2.0",
+            headers={},
+            params={
+                "startIndex": 0,
+                "resultsPerPage": 10,
+            },
+        )
+        self.assertEqual(cve.cpe_name_id, "CPE-1-1")
+
+        self.http_client.get.reset_mock()
+        cve = await anext(it)
+        self.assertEqual(cve.cpe_name_id, "CPE-1-2")
+        self.http_client.get.assert_not_called()
+
+        self.http_client.get.reset_mock()
+        cve = await anext(it)
+        self.http_client.get.assert_awaited_once_with(
+            "https://services.nvd.nist.gov/rest/json/cpes/2.0",
+            headers={},
+            params={
+                "startIndex": 2,
+                "resultsPerPage": 2,
+            },
+        )
+        self.assertEqual(cve.cpe_name_id, "CPE-2-1")
+
+        self.http_client.get.reset_mock()
+        cve = await anext(it)
+        self.assertEqual(cve.cpe_name_id, "CPE-2-2")
+        self.http_client.get.assert_not_called()
+
+        self.http_client.get.reset_mock()
+
+        with self.assertRaises(Exception):
+            cve = await anext(it)
+
     async def test_context_manager(self):
         async with self.api:
             pass
