@@ -336,6 +336,240 @@ class PEP440VersionTestCase(unittest.TestCase):
                 f"{version1} should not be greater then {version2}",
             )
 
+        versions = [
+            ("1.0.0", object()),
+            ("1.0.0", 1),
+            ("1.0.0", True),
+        ]
+        for version1, version2 in versions:
+            with self.assertRaisesRegex(ValueError, "Can't compare"):
+                self.assertFalse(Version.from_string(version1) > version2)
+
+    def test_greater_or_equal_then(self):
+        versions = [
+            ("1.0.0", "0.9.9999"),
+            ("1.0.1", "1.0.0"),
+            ("1.0.0", "1.0.0"),
+            ("1.0.0", "1.0.0.dev1"),
+            ("1.0.0", "1.0.0-alpha1"),
+            ("1.0.0", "1.0.0-alpha1"),
+            ("1.0.0", "1.0.0-beta1"),
+            ("1.0.0", "1.0.0-rc1"),
+            ("1.0.0.dev1", "1.0.0.dev1"),
+            ("1.0.0+dev1", "1.0.0+dev1"),
+            ("1.0.0-alpha1", "1.0.0-dev1"),
+            ("1.0.0-alpha1", "1.0.0-alpha1.dev1"),
+            ("1.0.0-alpha1", "1.0.0-alpha1"),
+            ("1.0.0-alpha2", "1.0.0-alpha1"),
+            ("1.0.0-alpha1.dev1", "1.0.0-alpha1.dev1"),
+            ("1.0.0-beta1", "1.0.0-dev1"),
+            ("1.0.0-beta1", "1.0.0-alpha1"),
+            ("1.0.0-beta1", "1.0.0-beta1"),
+            ("1.0.0-beta1", "1.0.0-beta1.dev1"),
+            ("1.0.0-beta2", "1.0.0-beta1"),
+            ("1.0.0-beta1.dev1", "1.0.0-beta1.dev1"),
+            ("1.0.0-rc1", "1.0.0-rc1"),
+            ("1.0.0-rc1", "1.0.0-dev1"),
+            ("1.0.0-rc1", "1.0.0-alpha1"),
+            ("1.0.0-rc1", "1.0.0-beta1"),
+            ("1.0.0-rc1", "1.0.0-rc1.dev1"),
+            ("1.0.0-rc1.dev1", "1.0.0-rc1.dev1"),
+            ("1.0.0-rc2", "1.0.0-rc1"),
+        ]
+        for version1, version2 in versions:
+            self.assertTrue(
+                Version.from_string(version1) >= Version.from_string(version2),
+                f"{version1} should be greater or equal then {version2}",
+            )
+
+        versions = [
+            ("1.0.0", "1.0.0+dev1"),
+            ("1.0.0.dev1", "1.0.0.dev2"),
+            ("1.0.0", "1.0.1"),
+            ("1.0.0-dev1", "1.0.0"),
+            ("1.0.0-dev1", "1.0.0-alpha1"),
+            ("1.0.0-dev1", "1.0.0-beta1"),
+            ("1.0.0-dev1", "1.0.0-rc1"),
+            ("1.0.0+dev1", "1.0.0+dev2"),
+            ("1.0.0-alpha1", "1.0.0-beta1"),
+            ("1.0.0-alpha1", "1.0.0-rc1"),
+            ("1.0.0-alpha1", "1.0.0-alpha1+dev1"),
+            ("1.0.0-alpha1.dev1", "1.0.0-alpha1.dev2"),
+            ("1.0.0-alpha1+dev1", "1.0.0-alpha1+dev2"),
+            ("1.0.0-beta1", "1.0.0-rc1"),
+            ("1.0.0-beta1", "1.0.0-beta1+dev1"),
+            ("1.0.0-beta1.dev1", "1.0.0-beta1.dev2"),
+            ("1.0.0-beta1+dev1", "1.0.0-beta1+dev2"),
+            ("1.0.0-rc1", "1.0.0"),
+            ("1.0.0-rc1", "1.0.0-rc1+dev1"),
+            ("1.0.0-rc1.dev1", "1.0.0-rc1.dev2"),
+            ("1.0.0-rc1+dev1", "1.0.0-rc1+dev2"),
+        ]
+        for version1, version2 in versions:
+            self.assertFalse(
+                Version.from_string(version1) >= Version.from_string(version2),
+                f"{version1} should not be greater or equal then {version2}",
+            )
+
+        versions = [
+            ("1.0.0", object()),
+            ("1.0.0", 1),
+            ("1.0.0", True),
+        ]
+        for version1, version2 in versions:
+            with self.assertRaisesRegex(ValueError, "Can't compare"):
+                self.assertFalse(Version.from_string(version1) >= version2)
+
+    def test_less_then(self):
+        versions = [
+            ("1.0.0", "0.9.9999"),
+            ("1.0.1", "1.0.0"),
+            ("1.0.0", "1.0.0.dev1"),
+            ("1.0.0", "1.0.0-alpha1"),
+            ("1.0.0", "1.0.0-alpha1"),
+            ("1.0.0", "1.0.0-beta1"),
+            ("1.0.0", "1.0.0-rc1"),
+            ("1.0.0-alpha1", "1.0.0-dev1"),
+            ("1.0.0-alpha1", "1.0.0-alpha1.dev1"),
+            ("1.0.0-alpha2", "1.0.0-alpha1"),
+            ("1.0.0-beta1", "1.0.0-dev1"),
+            ("1.0.0-beta1", "1.0.0-alpha1"),
+            ("1.0.0-beta1", "1.0.0-beta1.dev1"),
+            ("1.0.0-beta2", "1.0.0-beta1"),
+            ("1.0.0-rc1", "1.0.0-dev1"),
+            ("1.0.0-rc1", "1.0.0-alpha1"),
+            ("1.0.0-rc1", "1.0.0-beta1"),
+            ("1.0.0-rc1", "1.0.0-rc1.dev1"),
+            ("1.0.0-rc2", "1.0.0-rc1"),
+        ]
+        for version2, version1 in versions:
+            self.assertTrue(
+                Version.from_string(version1) < Version.from_string(version2),
+                f"{version1} should be less then {version2}",
+            )
+
+        versions = [
+            ("1.0.0", "1.0.0"),
+            ("1.0.0", "1.0.0+dev1"),
+            ("1.0.0.dev1", "1.0.0.dev1"),
+            ("1.0.0.dev1", "1.0.0.dev2"),
+            ("1.0.0", "1.0.1"),
+            ("1.0.0-dev1", "1.0.0"),
+            ("1.0.0-dev1", "1.0.0-alpha1"),
+            ("1.0.0-dev1", "1.0.0-beta1"),
+            ("1.0.0-dev1", "1.0.0-rc1"),
+            ("1.0.0+dev1", "1.0.0+dev1"),
+            ("1.0.0+dev1", "1.0.0+dev2"),
+            ("1.0.0-alpha1", "1.0.0-alpha1"),
+            ("1.0.0-alpha1", "1.0.0-beta1"),
+            ("1.0.0-alpha1", "1.0.0-rc1"),
+            ("1.0.0-alpha1", "1.0.0-alpha1+dev1"),
+            ("1.0.0-alpha1.dev1", "1.0.0-alpha1.dev1"),
+            ("1.0.0-alpha1.dev1", "1.0.0-alpha1.dev2"),
+            ("1.0.0-alpha1+dev1", "1.0.0-alpha1+dev2"),
+            ("1.0.0-beta1", "1.0.0-rc1"),
+            ("1.0.0-beta1", "1.0.0-beta1"),
+            ("1.0.0-beta1", "1.0.0-beta1+dev1"),
+            ("1.0.0-beta1.dev1", "1.0.0-beta1.dev1"),
+            ("1.0.0-beta1.dev1", "1.0.0-beta1.dev2"),
+            ("1.0.0-beta1+dev1", "1.0.0-beta1+dev2"),
+            ("1.0.0-rc1", "1.0.0"),
+            ("1.0.0-rc1", "1.0.0-rc1"),
+            ("1.0.0-rc1", "1.0.0-rc1+dev1"),
+            ("1.0.0-rc1.dev1", "1.0.0-rc1.dev1"),
+            ("1.0.0-rc1.dev1", "1.0.0-rc1.dev2"),
+            ("1.0.0-rc1+dev1", "1.0.0-rc1+dev2"),
+        ]
+        for version2, version1 in versions:
+            self.assertFalse(
+                Version.from_string(version1) < Version.from_string(version2),
+                f"{version1} should not be less then {version2}",
+            )
+
+        versions = [
+            ("1.0.0", object()),
+            ("1.0.0", 1),
+            ("1.0.0", True),
+        ]
+        for version1, version2 in versions:
+            with self.assertRaisesRegex(ValueError, "Can't compare"):
+                self.assertFalse(Version.from_string(version1) < version2)
+
+    def test_less_or_equal_then(self):
+        versions = [
+            ("1.0.0", "0.9.9999"),
+            ("1.0.1", "1.0.0"),
+            ("1.0.0", "1.0.0"),
+            ("1.0.0", "1.0.0.dev1"),
+            ("1.0.0", "1.0.0-alpha1"),
+            ("1.0.0", "1.0.0-alpha1"),
+            ("1.0.0", "1.0.0-beta1"),
+            ("1.0.0", "1.0.0-rc1"),
+            ("1.0.0.dev1", "1.0.0.dev1"),
+            ("1.0.0+dev1", "1.0.0+dev1"),
+            ("1.0.0-alpha1", "1.0.0-dev1"),
+            ("1.0.0-alpha1", "1.0.0-alpha1.dev1"),
+            ("1.0.0-alpha1", "1.0.0-alpha1"),
+            ("1.0.0-alpha2", "1.0.0-alpha1"),
+            ("1.0.0-alpha1.dev1", "1.0.0-alpha1.dev1"),
+            ("1.0.0-beta1", "1.0.0-dev1"),
+            ("1.0.0-beta1", "1.0.0-alpha1"),
+            ("1.0.0-beta1", "1.0.0-beta1"),
+            ("1.0.0-beta1", "1.0.0-beta1.dev1"),
+            ("1.0.0-beta2", "1.0.0-beta1"),
+            ("1.0.0-beta1.dev1", "1.0.0-beta1.dev1"),
+            ("1.0.0-rc1", "1.0.0-rc1"),
+            ("1.0.0-rc1", "1.0.0-dev1"),
+            ("1.0.0-rc1", "1.0.0-alpha1"),
+            ("1.0.0-rc1", "1.0.0-beta1"),
+            ("1.0.0-rc1", "1.0.0-rc1.dev1"),
+            ("1.0.0-rc1.dev1", "1.0.0-rc1.dev1"),
+            ("1.0.0-rc2", "1.0.0-rc1"),
+        ]
+        for version2, version1 in versions:
+            self.assertTrue(
+                Version.from_string(version1) <= Version.from_string(version2),
+                f"{version1} should be less or equal then {version2}",
+            )
+
+        versions = [
+            ("1.0.0", "1.0.0+dev1"),
+            ("1.0.0.dev1", "1.0.0.dev2"),
+            ("1.0.0", "1.0.1"),
+            ("1.0.0-dev1", "1.0.0"),
+            ("1.0.0-dev1", "1.0.0-alpha1"),
+            ("1.0.0-dev1", "1.0.0-beta1"),
+            ("1.0.0-dev1", "1.0.0-rc1"),
+            ("1.0.0+dev1", "1.0.0+dev2"),
+            ("1.0.0-alpha1", "1.0.0-beta1"),
+            ("1.0.0-alpha1", "1.0.0-rc1"),
+            ("1.0.0-alpha1", "1.0.0-alpha1+dev1"),
+            ("1.0.0-alpha1.dev1", "1.0.0-alpha1.dev2"),
+            ("1.0.0-alpha1+dev1", "1.0.0-alpha1+dev2"),
+            ("1.0.0-beta1", "1.0.0-rc1"),
+            ("1.0.0-beta1", "1.0.0-beta1+dev1"),
+            ("1.0.0-beta1.dev1", "1.0.0-beta1.dev2"),
+            ("1.0.0-beta1+dev1", "1.0.0-beta1+dev2"),
+            ("1.0.0-rc1", "1.0.0"),
+            ("1.0.0-rc1", "1.0.0-rc1+dev1"),
+            ("1.0.0-rc1.dev1", "1.0.0-rc1.dev2"),
+            ("1.0.0-rc1+dev1", "1.0.0-rc1+dev2"),
+        ]
+        for version2, version1 in versions:
+            self.assertFalse(
+                Version.from_string(version1) <= Version.from_string(version2),
+                f"{version1} should not be less or equal then {version2}",
+            )
+
+        versions = [
+            ("1.0.0", object()),
+            ("1.0.0", 1),
+            ("1.0.0", True),
+        ]
+        for version1, version2 in versions:
+            with self.assertRaisesRegex(ValueError, "Can't compare"):
+                self.assertFalse(Version.from_string(version1) <= version2)
+
     def test_is_dev_release(self):
         versions = [
             "1.0.0.dev1",
@@ -538,12 +772,20 @@ class PEP440VersionCalculatorTestCase(unittest.TestCase):
             f"19.{today.month}.1.dev3",
             f"{year_short}.{today.month}.1.dev3",
             f"{year_short}.{today.month}.1",
+            "2022.4.1",
+            "2023.5.1",
+            f"{today.year}.{today.month}.1.dev2",
+            f"{today.year}.{today.month}.1",
         ]
         assert_versions = [
             f"{year_short}.{today.month}.0",
             f"{year_short}.{today.month}.0",
             f"{year_short}.{today.month}.1",
             f"{year_short}.{today.month}.2",
+            f"{today.year}.{today.month}.0",
+            f"{today.year}.{today.month}.0",
+            f"{today.year}.{today.month}.1",
+            f"{today.year}.{today.month}.2",
         ]
 
         for current_version, assert_version in zip(
@@ -571,6 +813,11 @@ class PEP440VersionCalculatorTestCase(unittest.TestCase):
                 Version.from_string(f"{year_short}.{today.month + 1}.0")
             )
 
+        with self.assertRaisesRegex(VersionError, "'.+' is higher than '.+'."):
+            calculator.next_calendar_version(
+                Version.from_string(f"{today.year + 1}.{today.month + 1}.0")
+            )
+
     def test_next_minor_version(self):
         calculator = VersionCalculator()
 
